@@ -238,13 +238,13 @@ def get_chart(
             Example :
                 request = Chart.Request()
                 request.requestid = '1'
-                request.resolution = Chart.Resolution.PT1M
+                request.resolution = Chart.Interval.PT1M
                 request.culture = 'fr-FR'
                 request.series.append('issueid:360148977')
                 request.series.append('price:issueid:360148977')
                 request.series.append('ohlc:issueid:360148977')
                 request.series.append('volume:issueid:360148977')
-                request.period = Chart.Period.P1D
+                request.period = Chart.Interval.P1D
                 request.tz = 'Europe/Paris'
         user_token (int):
             User identifier in Degiro's API.
